==> ec2-0.33.0-sources.jar: software/amazon/awscdk/services/ec2/IcmpAllTypeCodes.java <==
package software.amazon.awscdk.services.ec2;

/**
 * All ICMP Codes for a given ICMP Type.
 */
@javax.annotation.Generated(value = "jsii-pacmak/0.11.0 (build 3d6415e)", date = "2019-05-30T15:03:30.394Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.ec2.$Module.class, fqn = "@aws-cdk/aws-ec2.IcmpAllTypeCodes")
public class IcmpAllTypeCodes extends software.amazon.jsii.JsiiObject implements software.amazon.awscdk.services.ec2.IPortRange {
    protected IcmpAllTypeCodes(final software.amazon.jsii.JsiiObject.InitializationMode mode) {
        super(mode);
    }
    public IcmpAllTypeCodes(final java.lang.Number type) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.Jsii);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { java.util.Objects.requireNonNull(type, "type is required") });
    }

    /**
     * Produce the ingress/egress rule JSON for the given connection.
     */
    @Override
    @javax.annotation.Nullable
    public java.lang.Object toRuleJSON() {
        return this.jsiiCall("toRuleJSON", java.lang.Object.class);
    }

    /**
     * Returns a string representation of an object.
     */
    public java.lang.String toString() {
        return this.jsiiCall("toString", java.lang.String.class);
    }

    /**
     * Whether the rule containing this port range can be inlined into a securitygroup or not.
     */
    @Override
    public java.lang.Boolean getCanInlineRule() {
        return this.jsiiGet("canInlineRule", java.lang.Boolean.class);
    }

    public java.lang.Number getType() {
        return this.jsiiGet("type", java.lang.Number.class);
    }
}

==> ec2-0.34.0-sources.jar: software/amazon/awscdk/services/ec2/IcmpAllTypeCodes.java <==
package software.amazon.awscdk.services.ec2;

/**
 * All ICMP Codes for a given ICMP Type.
 * 
 * EXPERIMENTAL
 */
@javax.annotation.Generated(value = "jsii-pacmak/0.11.2 (build 27d16c2)", date = "2019-06-10T11:04:59.489Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.ec2.$Module.class, fqn = "@aws-cdk/aws-ec2.IcmpAllTypeCodes")
public class IcmpAllTypeCodes extends software.amazon.jsii.JsiiObject implements software.amazon.awscdk.services.ec2.IPortRange {
    protected IcmpAllTypeCodes(final software.amazon.jsii.JsiiObject.InitializationMode mode) {
        super(mode);
    }
    /**
     * EXPERIMENTAL
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public IcmpAllTypeCodes(final java.lang.Number type) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.Jsii);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { java.util.Objects.requireNonNull(type, "type is required") });
    }

    /**
     * Produce the ingress/egress rule JSON for the given connection.
     * 
     * EXPERIMENTAL
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    @Override
    @javax.annotation.Nullable
    public java.lang.Object toRuleJSON() {
        return this.jsiiCall("toRuleJSON", java.lang.Object.class);
    }

    /**
     * Returns a string representation of an object.
     * 
     * EXPERIMENTAL
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public java.lang.String toString() {
        return this.jsiiCall("toString", java.lang.String.class);
    }

    /**
     * Whether the rule containing this port range can be inlined into a securitygroup or not.
     * 
     * EXPERIMENTAL
     */
    @Override
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public java.lang.Boolean getCanInlineRule() {
        return this.jsiiGet("canInlineRule", java.lang.Boolean.class);
    }

    /**
     * EXPERIMENTAL
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public java.lang.Number getType() {
        return this.jsiiGet("type", java.lang.Number.class);
    }
}
